library(raster)
library(rgdal)
library(GGally)

# sonoran desert
s_eco = shapefile('gis resources/NA_CEC_Eco_Level3/NA_CEC_Eco_Level3.shp')
s_sonorandesert = s_eco[s_eco$NA_L3NAME=="Sonoran Desert",]

shapefile(s_sonorandesert, file='gis resources/outputs/sonoran_desert.shp')

r_sonorandesert_10km = rasterize(s_sonorandesert, raster(res=10000, ext=extent(s_sonorandesert), crs=projection(s_sonorandesert)))>0
r_sonorandesert_25km = rasterize(s_sonorandesert, raster(res=25000, ext=extent(s_sonorandesert), crs=projection(s_sonorandesert)))>0
r_sonorandesert_50km = rasterize(s_sonorandesert, raster(res=50000, ext=extent(s_sonorandesert), crs=projection(s_sonorandesert)))>0

# north america
s_cont = shapefile('gis resources/continent/continent.shp')
s_na = s_cont[s_cont$CONTINENT=="North America",]
s_na = crop(s_na, extent(-180,0,0,100))
s_na = spTransform(s_na, projection(s_sonorandesert))

r_na_10km = rasterize(s_na, raster(res=10000, ext=extent(s_na), crs=projection(s_na)))>0
r_na_25km = rasterize(s_na, raster(res=25000, ext=extent(s_na), crs=projection(s_na)))>0
r_na_50km = rasterize(s_na, raster(res=50000, ext=extent(s_na), crs=projection(s_na)))>0


# clip sonoran desert to below 1219m
r_elev = raster('gis resources/mn30_grd/mn30_grd/w001000.adf')
r_elev_10km = projectRaster(r_elev, r_sonorandesert_10km)
r_elev_25km = projectRaster(r_elev, r_sonorandesert_25km)
r_elev_50km = projectRaster(r_elev, r_sonorandesert_50km)

r_sonorandesert_masked_10km = mask(r_sonorandesert_10km, r_elev_10km<1219,maskvalue=0)
r_sonorandesert_masked_25km = mask(r_sonorandesert_25km, r_elev_25km<1219,maskvalue=0)
r_sonorandesert_masked_50km = mask(r_sonorandesert_50km, r_elev_50km<1219,maskvalue=0)

# fraction of area lost byclipping
1 - sum(getValues(r_sonorandesert_masked_25km),na.rm=T) / sum(getValues(r_sonorandesert_25km),na.rm=T)
1 - sum(getValues(r_sonorandesert_masked_50km),na.rm=T) / sum(getValues(r_sonorandesert_50km),na.rm=T)


# project CHELSA data
r_bio01 = raster('gis resources/chelsa_V1climatologies/CHELSA_bio10_01.tif')
r_bio05 = raster('gis resources/chelsa_V1climatologies/CHELSA_bio10_05.tif')
r_bio06 = raster('gis resources/chelsa_V1climatologies/CHELSA_bio10_06.tif')
r_bio12 = raster('gis resources/chelsa_V1climatologies/CHELSA_bio10_12.tif')
r_bio13 = raster('gis resources/chelsa_V1climatologies/CHELSA_bio10_13.tif')
r_bio14 = raster('gis resources/chelsa_V1climatologies/CHELSA_bio10_14.tif')

r_climate = stack(r_bio01, r_bio05, r_bio06, r_bio12, r_bio13, r_bio14)

# get correlation among variables
vals_climate = sampleRandom(r_climate,size=1000)
g_pairs = ggpairs(as.data.frame(vals_climate)) + theme_bw()
ggsave(g_pairs,file='g_pairs.png',width=8,height=8)

r_climate_10km = projectRaster(r_climate, r_na_10km)
writeRaster(r_climate_10km,file='gis resources/outputs/r_climate_10km.tif',bylayer=TRUE,suffix='names')
rm(r_climate_10km)

r_climate_25km = projectRaster(r_climate, r_na_25km)
writeRaster(r_climate_25km,file='gis resources/outputs/r_climate_25km.tif',bylayer=TRUE,suffix='names')
rm(r_climate_25km)

r_climate_50km = projectRaster(r_climate, r_na_50km)
writeRaster(r_climate_50km,file='gis resources/outputs/r_climate_50km.tif',bylayer=TRUE,suffix='names')
rm(r_climate_50km)


# write outputs
writeRaster(r_sonorandesert_masked_10km, 'gis resources/outputs/r_sonorandesert_masked_10km.tif',overwrite=TRUE)
writeRaster(r_sonorandesert_masked_25km, 'gis resources/outputs/r_sonorandesert_masked_25km.tif',overwrite=TRUE)
writeRaster(r_sonorandesert_masked_50km, 'gis resources/outputs/r_sonorandesert_masked_50km.tif',overwrite=TRUE)

writeRaster(r_na_10km, 'gis resources/outputs/r_na_10km.tif',overwrite=TRUE)
writeRaster(r_na_25km, 'gis resources/outputs/r_na_25km.tif',overwrite=TRUE)
writeRaster(r_na_50km, 'gis resources/outputs/r_na_50km.tif',overwrite=TRUE)
