library(dplyr)
library(data.table)
library(raster)

# put data into paired short format

data_carolyn = read.csv('carolyn data/march.ensemble.NARP.splist.csv')

row_to_char <- function(df, Food.species, type)
{
  species_names = df %>% as.list %>% sapply(as.character)
  species_names[species_names==""] = NA
  species_names = as.character(na.omit(species_names))
  
  if (length(species_names) > 0)
  {
    species_names = data.frame(Food.species=Food.species,Contrast.species=species_names,type=type)
  }
  else
  {
    species_names = data.frame(Food.species=Food.species,Contrast.species=NA,type=type)
  }
  
  return(species_names)
}

process_row <- function(df)
{
  stopifnot(nrow(df)==1)
  
  basename = df$Food.species[1]
  
  df_sister = df %>% dplyr::select("Sister.one","Sister.two","Sister.three","Sister.four") %>% 
    row_to_char(Food.species=basename,type="Sister")
  df_sister_used = df %>% dplyr::select("Sister.one.used","Sister.two.used","Sister.three.used","Sister.four.used") %>% 
    row_to_char(Food.species=basename,type="Sister_used")
  df_congener = df %>% dplyr::select("Congener.one","Congener.two","Congener.three","Congener.four","Congener.five","Congener.six") %>% 
    row_to_char(Food.species=basename,type="Congener")
  df_congener_used = df %>% dplyr::select("Congener.one.used","Congener.two.used","Congener.three.used","Congener.four.used","Congener.five.used","Congener.six.used") %>% 
    row_to_char(Food.species=basename,type="Congener_used")
  df_random_congener = df %>% dplyr::select("Random.congener.one","Random.congener.two","Random.congener.three","Random.congener.four","Random.congener.five","Random.congener.six") %>% 
    row_to_char(Food.species=basename,type="Random")
  df_random_congener_used = df %>% dplyr::select("Random.congener.one.used","Random.congener.two.used","Random.congener.three.used","Random.congener.four.used","Random.congener.five.used") %>% 
    row_to_char(Food.species=basename,type="Random_used")
  
    
  result = rbind(df_sister, df_sister_used, df_congener, df_congener_used, df_random_congener, df_random_congener_used)
  
  return(result)
}

data_short_list = lapply(1:nrow(data_carolyn), function(x) { process_row(data_carolyn[x,])  })
data_short = rbindlist(data_short_list)
data_short = data_short %>% 
  arrange(Food.species,type,Contrast.species) %>% 
  dplyr::select(Food.species,type,Contrast.species)

# flag used species
data_short$Contrast.used = as.numeric(grepl("used",data_short$type)) 
data_short$Contrast.type = gsub("_used","",data_short$type)

data_short = data_short %>% dplyr::select(-type)


# identify sonoran desert range overlaps
s_sonorandesert = shapefile('gis resources/outputs/sonoran_desert.shp')
proj_latlon = "+proj=longlat +datum=WGS84 +ellps=WGS84 +towgs84=0,0,0"
s_sonorandesert_latlon = spTransform(s_sonorandesert, proj_latlon)

files_occurrences = dir(path='occurrence data/',pattern='*csv$',full.names = TRUE)
occurrences_all = do.call("rbind",lapply(files_occurrences, read.csv))
occurrences_all_sp = SpatialPoints(occurrences_all %>% dplyr::select(longitude,latitude))
crs(occurrences_all_sp) = proj_latlon

# see which points are in the sonoran desert
inout = over(occurrences_all_sp, s_sonorandesert_latlon)
occurrences_all$inout = !is.na(inout$NA_L3NAME)

# any species with at least one sd occurrence counts
df_in_sd = occurrences_all %>% 
  rename(Contrast.species = Species) %>%
  group_by(Contrast.species) %>%
  summarize(Contrast.in.Sonoran.Desert=any(inout))

data_joined = left_join(data_short, df_in_sd, by='Contrast.species')


write.csv(data_joined, 'carolyn data/specieslist_sonorandesert_short.csv',row.names=F)

# make a copy for supporting information
write.csv(data_joined, 'File S1 - specieslist_sonorandesert_short.csv',row.names=F)


dj = read.csv('carolyn data/specieslist_sonorandesert_short.csv')

dj_in_sd = dj %>% filter(Contrast.in.Sonoran.Desert==TRUE)
length(unique(dj_in_sd$Food.species))
length(unique(dj_in_sd$Contrast.species))
